# -*- coding: UTF-8 -*-
# Copyright 2020 Xiaomi, Inc.

import json
import re

ceph_name_regex_pattern = re.compile("^[a-z0-9.\\-]{2,10}$")
ceph_capacity_regex_pattern = re.compile("^[1-9][0-9]*[TGMtgm]$")


class CephVolume(object):
  """Class for ceph service method.
  """

  def __init__(self,
               ceph_name,
               capacity):
    self.ceph_name = ceph_name
    self.capacity = capacity

  @property
  def ceph_name(self):
    return self._ceph_name

  @ceph_name.setter
  def ceph_name(self, value):
    if not isinstance(value, str):
      raise ValueError("ceph_name must be a string!")
    if value == "":
      raise ValueError("ceph_name cannot be None!")
    if not ceph_name_regex_pattern.match(value):
      raise ValueError("ceph name must be a lower-case alphanumeric string of up to 10 characters")
    self._ceph_name = value

  @property
  def capacity(self):
    return self._capacity

  @capacity.setter
  def capacity(self, value):
    if not isinstance(value, str):
      raise ValueError("capacity must be a string!")
    if value == "":
      raise ValueError("capacity cannot be None!")
    if not ceph_capacity_regex_pattern.match(value):
      raise ValueError("ceph capacity must be string, e.g. 2M, 3G, 4T")
    self._capacity = value

  def get_json_data(self):
    data = {
        "ceph_name": self._ceph_name,
        "capacity": self._capacity
    }
    return json.dumps(data)
